==> estateplat-common-1.2.3-20180710.104808-145-sources.jar: cn/gtmap/estateplat/model/exchange/court/GxPeKzqq.java <==
package cn.gtmap.estateplat.model.exchange.court;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import java.io.Serializable;
import java.util.Date;
import java.util.List;

/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2018/6/27
 * @description
 */
@XmlRootElement(name = "BDCKZQQ")
@Table(name = "gx_pe_kzqq")
public class GxPeKzqq implements Serializable {
    @Id
    private String cxqqid;//查询请求主键id
    private String cxqqdh;//控制请求单号
    private String lb;//类别
    private String xz;//性质
    private String xm;//被查询人姓名
    private String gj;//国家或地区
    private String zjzl;//证件种类
    private String zjh;//证件号
    private String fzjg;//发证机关所在地
    private String fymc;//执行法院名称
    private String cbr;//承办法官
    private String ah;//执行案号
    private String ckh;//控制通知书名称
    private String zt;//状态
    private Date cjsj;//创建时间
    private Date gxsj;//更新时间
    private Date sbsj;//上报时间

    private List<GxPeKzqqXm> gxPeKzqqXmList;

    @XmlTransient
    public String getCxqqid() {
        return cxqqid;
    }

    public void setCxqqid(String cxqqid) {
        this.cxqqid = cxqqid;
    }

    @XmlElement(name = "CXQQDH")
    public String getCxqqdh() {
        return cxqqdh;
    }

    public void setCxqqdh(String cxqqdh) {
        this.cxqqdh = cxqqdh;
    }

    @XmlTransient
    public String getLb() {
        return lb;
    }

    public void setLb(String lb) {
        this.lb = lb;
    }

    @XmlElement(name = "XZ")
    public String getXz() {
        return xz;
    }

    public void setXz(String xz) {
        this.xz = xz;
    }

    @XmlElement(name = "XM")
    public String getXm() {
        return xm;
    }

    public void setXm(String xm) {
        this.xm = xm;
    }

    @XmlElement(name = "GJ")
    public String getGj() {
        return gj;
    }

    public void setGj(String gj) {
        this.gj = gj;
    }

    @XmlElement(name = "ZJZL")
    public String getZjzl() {
        return zjzl;
    }

    public void setZjzl(String zjzl) {
        this.zjzl = zjzl;
    }

    @XmlElement(name = "ZJH")
    public String getZjh() {
        return zjh;
    }

    public void setZjh(String zjh) {
        this.zjh = zjh;
    }

    @XmlElement(name = "FZJG")
    public String getFzjg() {
        return fzjg;
    }

    public void setFzjg(String fzjg) {
        this.fzjg = fzjg;
    }

    @XmlElement(name = "FYMC")
    public String getFymc() {
        return fymc;
    }

    public void setFymc(String fymc) {
        this.fymc = fymc;
    }

    @XmlElement(name = "CBR")
    public String getCbr() {
        return cbr;
    }

    public void setCbr(String cbr) {
        this.cbr = cbr;
    }

    @XmlElement(name = "AH")
    public String getAh() {
        return ah;
    }

    public void setAh(String ah) {
        this.ah = ah;
    }

    @XmlElement(name = "CKH")
    public String getCkh() {
        return ckh;
    }

    public void setCkh(String ckh) {
        this.ckh = ckh;
    }

    @XmlTransient
    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    @XmlTransient
    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    @XmlTransient
    public Date getGxsj() {
        return gxsj;
    }

    public void setGxsj(Date gxsj) {
        this.gxsj = gxsj;
    }

    @XmlTransient
    public Date getSbsj() {
        return sbsj;
    }

    public void setSbsj(Date sbsj) {
        this.sbsj = sbsj;
    }

    @Transient
    @XmlElement(name = "BDCQLLIST ")
    public List<GxPeKzqqXm> getGxPeKzqqXmList() {
        return gxPeKzqqXmList;
    }

    public void setGxPeKzqqXmList(List<GxPeKzqqXm> gxPeKzqqXmList) {
        this.gxPeKzqqXmList = gxPeKzqqXmList;
    }
}

==> estateplat-common-1.2.3-20180710.110252-147-sources.jar: cn/gtmap/estateplat/model/exchange/court/GxPeKzqq.java <==
package cn.gtmap.estateplat.model.exchange.court;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import java.io.Serializable;
import java.util.Date;
import java.util.List;

/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2018/6/27
 * @description
 */
@XmlRootElement(name = "BDCKZQQ")
@Table(name = "gx_pe_kzqq")
public class GxPeKzqq implements Serializable {
    @Id
    private String cxqqid;//查询请求主键id
    private String cxqqdh;//控制请求单号
    private String lb;//类别
    private String xz;//性质
    private String xm;//被查询人姓名
    private String gj;//国家或地区
    private String zjzl;//证件种类
    private String zjh;//证件号
    private String fzjg;//发证机关所在地
    private String fymc;//执行法院名称
    private String cbr;//承办法官
    private String ah;//执行案号
    private String ckh;//控制通知书名称
    private String zt;//状态
    private Date cjsj;//创建时间
    private Date gxsj;//更新时间
    private Date sbsj;//上报时间

    private GxFyCxqqxmDataModel gxFyCxqqxmDataModel;

    @XmlTransient
    public String getCxqqid() {
        return cxqqid;
    }

    public void setCxqqid(String cxqqid) {
        this.cxqqid = cxqqid;
    }

    @XmlElement(name = "CXQQDH")
    public String getCxqqdh() {
        return cxqqdh;
    }

    public void setCxqqdh(String cxqqdh) {
        this.cxqqdh = cxqqdh;
    }

    @XmlTransient
    public String getLb() {
        return lb;
    }

    public void setLb(String lb) {
        this.lb = lb;
    }

    @XmlElement(name = "XZ")
    public String getXz() {
        return xz;
    }

    public void setXz(String xz) {
        this.xz = xz;
    }

    @XmlElement(name = "XM")
    public String getXm() {
        return xm;
    }

    public void setXm(String xm) {
        this.xm = xm;
    }

    @XmlElement(name = "GJ")
    public String getGj() {
        return gj;
    }

    public void setGj(String gj) {
        this.gj = gj;
    }

    @XmlElement(name = "ZJZL")
    public String getZjzl() {
        return zjzl;
    }

    public void setZjzl(String zjzl) {
        this.zjzl = zjzl;
    }

    @XmlElement(name = "ZJH")
    public String getZjh() {
        return zjh;
    }

    public void setZjh(String zjh) {
        this.zjh = zjh;
    }

    @XmlElement(name = "FZJG")
    public String getFzjg() {
        return fzjg;
    }

    public void setFzjg(String fzjg) {
        this.fzjg = fzjg;
    }

    @XmlElement(name = "FYMC")
    public String getFymc() {
        return fymc;
    }

    public void setFymc(String fymc) {
        this.fymc = fymc;
    }

    @XmlElement(name = "CBR")
    public String getCbr() {
        return cbr;
    }

    public void setCbr(String cbr) {
        this.cbr = cbr;
    }

    @XmlElement(name = "AH")
    public String getAh() {
        return ah;
    }

    public void setAh(String ah) {
        this.ah = ah;
    }

    @XmlElement(name = "CKH")
    public String getCkh() {
        return ckh;
    }

    public void setCkh(String ckh) {
        this.ckh = ckh;
    }

    @XmlTransient
    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    @XmlTransient
    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    @XmlTransient
    public Date getGxsj() {
        return gxsj;
    }

    public void setGxsj(Date gxsj) {
        this.gxsj = gxsj;
    }

    @XmlTransient
    public Date getSbsj() {
        return sbsj;
    }

    public void setSbsj(Date sbsj) {
        this.sbsj = sbsj;
    }

    @Transient
    @XmlElement(name = "BDCQLLIST ")
    public GxFyCxqqxmDataModel getGxFyCxqqxmDataModel() {
        return gxFyCxqqxmDataModel;
    }

    public void setGxFyCxqqxmDataModel(GxFyCxqqxmDataModel gxFyCxqqxmDataModel) {
        this.gxFyCxqqxmDataModel = gxFyCxqqxmDataModel;
    }
}
